@@ -26,6 +26,10 @@
 #define PREFERENCES_VERSION_BEFORE(i1, i2, i3) (preferences_version[0] < i1 || (preferences_version[0] == i1 && (preferences_version[1] < i2 || (preferences_version[1] == i2 && preferences_version[2] < i3))))
 #define PREFERENCES_VERSION_AFTER(i1, i2, i3) (preferences_version[0] > i1 || (preferences_version[0] == i1 && (preferences_version[1] > i2 || (preferences_version[1] == i2 && preferences_version[2] > i3))))
 
+#define RESET_TZ 	printops.custom_time_zone = (rounding_mode == 2 ? TZ_TRUNCATE : 0);\
+			if(use_duo_syms) printops.custom_time_zone += TZ_DOZENAL;\
+			printops.time_zone = TIME_ZONE_LOCAL;
+
 extern int b_busy;
 
 bool can_display_unicode_string_function(const char*, void*) {
@@ -104,10 +108,12 @@ QalculateQtSettings::QalculateQtSettings() {
 			if(strcmp(line, "ignore_locale=1\n") == 0) {
 				ignore_locale = true;
 				b1 = true; if(b2) break;
-				break;
 			} else if(strcmp(line, "ignore_locale=0\n") == 0) {
 				b1 = true; if(b2) break;
-				break;
+			} else if(strlen(line) > 9 && strncmp(line, "language=", 9) == 0) {
+				custom_lang = (line + sizeof(char) * 9);
+				custom_lang.chop(1);
+				b1 = true; if(b2) break;
 			} else if(strcmp(line, "allow_multiple_instances=1\n") == 0) {
 				allow_multiple_instances = 1;
 				b2 = true; if(b1) break;
@@ -398,12 +404,12 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 		}
 	} else if(svar == "round_halfway_to_even") {
 		printops.round_halfway_to_even = v;
-		printops.custom_time_zone = 0;
 		rounding_mode = (v ? 1 : 0);
+		RESET_TZ
 	} else if(svar == "rounding_mode") {
 		if(v >= 0 && v <= 2) {
 			rounding_mode = v;
-			printops.custom_time_zone = (v == 2 ? -21586 : 0);
+			RESET_TZ
 			printops.round_halfway_to_even = (v == 1);
 		}
 	} else if(svar == "approximation") {
@@ -512,6 +518,8 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 			colorize_result = v;
 		} else if(svar == "format") {
 			format_result = v;
+		} else if(svar == "language") {
+			custom_lang = QString::fromStdString(svalue);
 		} else if(svar == "ignore_locale") {
 			ignore_locale = v;
 		} else if(svar == "window_title_mode") {
@@ -618,6 +626,9 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 			printops.lower_case_e = v;
 		} else if(svar == "lower_case_numbers") {
 			printops.lower_case_numbers = v;
+		} else if(svar == "duodecimal_symbols") {
+			use_duo_syms = v;
+			RESET_TZ
 		} else if(svar == "imaginary_j") {
 			do_imaginary_j = v;
 		} else if(svar == "base_display") {
@@ -711,6 +722,7 @@ void QalculateQtSettings::loadPreferences() {
 	printops.excessive_parenthesis = false;
 	printops.allow_non_usable = false;
 	printops.lower_case_numbers = false;
+	use_duo_syms = false;
 	printops.lower_case_e = false;
 	printops.base_display = BASE_DISPLAY_SUFFIX;
 	printops.twos_complement = true;
@@ -859,8 +871,8 @@ void QalculateQtSettings::loadPreferences() {
 	max_plot_time = 5;
 
 	preferences_version[0] = 4;
-	preferences_version[1] = 5;
-	preferences_version[2] = 1;
+	preferences_version[1] = 6;
+	preferences_version[2] = 0;
 
 	if(file) {
 		char line[1000000L];
@@ -1118,6 +1130,7 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 	fprintf(file, "version=%s\n", qApp->applicationVersion().toUtf8().data());
 	if(!is_workspace) {
 		fprintf(file, "allow_multiple_instances=%i\n", allow_multiple_instances);
+		if(!custom_lang.isEmpty()) fprintf(file, "language=%s\n", custom_lang.toUtf8().data());
 		fprintf(file, "ignore_locale=%i\n", ignore_locale);
 		fprintf(file, "check_version=%i\n", check_version);
 		if(check_version) {
@@ -1243,6 +1256,7 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 		fprintf(file, "hexadecimal_twos_complement=%i\n", printops.hexadecimal_twos_complement);
 		fprintf(file, "use_unicode_signs=%i\n", printops.use_unicode_signs);
 		fprintf(file, "lower_case_numbers=%i\n", printops.lower_case_numbers);
+		fprintf(file, "duodecimal_symbols=%i\n", use_duo_syms);
 		fprintf(file, "e_notation=%i\n", printops.lower_case_e);
 		fprintf(file, "imaginary_j=%i\n", CALCULATOR->getVariableById(VARIABLE_ID_I)->hasName("j") > 0);
 		fprintf(file, "base_display=%i\n", printops.base_display);
